'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _error = require('./error');

var _error2 = _interopRequireDefault(_error);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getErrorMessage(error, resp) {
  if (resp && resp.statusCode) {
    return resp.statusCode;
  }

  return error.code;
}

// There is an issue with new Sheets causing the string ")]}'" to be
// prepended to the JSON output when the X-DataSource-Auth is added.
// Until this is fixed, load as text and manually strip with regex. :(
// https://github.com/google/google-visualization-issues/issues/1928
function get(response, callback) {
  var transportOptions = {
    headers: {
      'X-DataSource-Auth': 'true'
    },
    timeout: 5000,
    url: response.request.url
  };

  (0, _request2.default)(transportOptions, function (error, resp, body) {
    if (!error && resp.statusCode === 200) {
      var data = JSON.parse(body.replace(/^\)\]\}'\n/, ''));
      response.loadData(data, callback);
      return;
    }

    callback(new _error2.default('Request failed.', getErrorMessage(error, resp)));
  });
}

exports.default = get;
module.exports = exports['default'];